@@ -40,7 +40,7 @@ InvalidComponent: ...
 """
 
 from stdnum.exceptions import *
-from stdnum.util import clean
+from stdnum.util import clean, isdigits
 
 
 def compact(number):
@@ -62,12 +62,12 @@ def split(number):
 def validate(number):
     """Check if the number provided is a valid IMSI."""
     number = compact(number)
-    if not number.isdigit():
+    if not isdigits(number):
         raise InvalidFormat()
     if len(number) not in (14, 15):
         raise InvalidLength()
-    if len(split(number)) != 3:
-        raise InvalidComponent()
+    if len(split(number)) < 2:
+        raise InvalidComponent()  # unknown MCC
     return number
 
 
