@@ -1,6 +1,6 @@
 # ismn.py - functions for handling ISMNs
 #
-# Copyright (C) 2010, 2011, 2012, 2013 Arthur de Jong
+# Copyright (C) 2010-2017 Arthur de Jong
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -54,16 +54,20 @@ def compact(number):
 
 
 def validate(number):
-    """Checks to see if the number provided is a valid ISMN (either a legacy
-    10-digit one or a 13-digit one). This checks the length and the check
-    bit but does not check if the publisher is known."""
+    """Check if the number provided is a valid ISMN (either a legacy 10-digit
+    one or a 13-digit one). This checks the length and the check bit but does
+    not check if the publisher is known."""
     number = compact(number)
     if len(number) == 10:
         if number[0] != 'M':
             raise InvalidFormat()
         ean.validate('9790' + number[1:])
-    else:
+    elif len(number) == 13:
+        if not number.startswith('9790'):
+            raise InvalidComponent()
         ean.validate(number)
+    else:
+        raise InvalidLength()
     return number
 
 
@@ -76,14 +80,14 @@ def ismn_type(number):
         return None
     if len(number) == 10:
         return 'ISMN10'
-    elif len(number) == 13:
+    else:  # len(number) == 13:
         return 'ISMN13'
 
 
 def is_valid(number):
-    """Checks to see if the number provided is a valid ISMN (either a legacy
-    10-digit one or a 13-digit one). This checks the length and the check
-    bit but does not check if the publisher is known."""
+    """Check if the number provided is a valid ISMN (either a legacy 10-digit
+    one or a 13-digit one). This checks the length and the check bit but does
+    not check if the publisher is known."""
     try:
         return bool(validate(number))
     except ValidationError:
@@ -117,15 +121,15 @@ def split(number):
     6 digits) and a check digit."""
     # clean up number
     number = to_ismn13(compact(number))
-    # rind the correct range and split the number
-    for length, low, high in _ranges:
+    # find the correct range and split the number
+    for length, low, high in _ranges:  # pragma: no branch (all ranges covered)
         if low <= number[4:4 + length] <= high:
             return (number[:3], number[3], number[4:4 + length],
                     number[4 + length:-1], number[-1])
 
 
 def format(number, separator='-'):
-    """Reformat the passed number to the standard format with the
+    """Reformat the number to the standard presentation format with the
     prefixes, the publisher element, the item element and the check-digit
     separated by the specified separator. The number is converted to the
     13-digit format silently."""
