@@ -1,4 +1,4 @@
-# mod_37_36.py - functions for performing the ISO 7064 Mod 37, 36 algorithm
+# mod_11_10.py - functions for performing the ISO 7064 Mod 11, 10 algorithm
 #
 # Copyright (C) 2010, 2011, 2012, 2013 Arthur de Jong
 #
@@ -17,50 +17,45 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""The ISO 7064 Mod 37, 36 algorithm.
+"""The ISO 7064 Mod 11, 10 algorithm.
 
-The Mod 37, 36 algorithm uses an alphanumeric check digit and the number
-itself may also contain letters.
+The Mod 11, 10 algorithm uses a number of calculations modulo 11 and 10 to
+determine a checksum.
 
->>> checksum('A12425GABC1234002M')
-1
->>> calc_check_digit('A12425GABC1234002')
-'M'
->>> validate('A12425GABC1234002M')
-'A12425GABC1234002M'
+For a module that can do generic Mod x+1, x calculations see the
+:mod:`stdnum.iso7064.mod_37_36` module.
 
-By changing the alphabet this can be turned into any Mod x+1, x
-algorithm. For example Mod 11, 10:
-
->>> calc_check_digit('00200667308', alphabet='0123456789')
+>>> calc_check_digit('79462')
+'3'
+>>> validate('794623')
+'794623'
+>>> calc_check_digit('00200667308')
 '5'
->>> validate('002006673085', alphabet='0123456789')
+>>> validate('002006673085')
 '002006673085'
 """
 
 from stdnum.exceptions import *
 
 
-def checksum(number, alphabet='0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ'):
+def checksum(number):
     """Calculate the checksum. A valid number should have a checksum of 1."""
-    modulus = len(alphabet)
-    check = modulus // 2
+    check = 5
     for n in number:
-        check = (((check or modulus) * 2) % (modulus + 1) + alphabet.index(n)) % modulus
+        check = (((check or 10) * 2) % 11 + int(n)) % 10
     return check
 
 
-def calc_check_digit(number, alphabet='0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ'):
+def calc_check_digit(number):
     """Calculate the extra digit that should be appended to the number to
     make it a valid number."""
-    modulus = len(alphabet)
-    return alphabet[(1 - ((checksum(number, alphabet) or modulus) * 2) % (modulus + 1)) % modulus]
+    return str((1 - ((checksum(number) or 10) * 2) % 11) % 10)
 
 
-def validate(number, alphabet='0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ'):
+def validate(number):
     """Check whether the check digit is valid."""
     try:
-        valid = checksum(number, alphabet) == 1
+        valid = checksum(number) == 1
     except Exception:
         raise InvalidFormat()
     if not valid:
@@ -68,9 +63,9 @@ def validate(number, alphabet='0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ'):
     return number
 
 
-def is_valid(number, alphabet='0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ'):
+def is_valid(number):
     """Check whether the check digit is valid."""
     try:
-        return bool(validate(number, alphabet))
+        return bool(validate(number))
     except ValidationError:
         return False
